from enum import Enum


class PatternTypes(str, Enum):
    BASE = "base"
    USERNAME = "username"
    PASSWORD = "password"
    EMAIL = "email"
    PHONE_NUMBER = "phone number"
    IP_ADDRESS = "IP adress"
    DATE = "date"
    ASCII = "ascii"
    URL = "url"
    SSN = "ssn"
    SEMANTIC_VERSIONING = "semantic versioning"
    UUID = "UUID"
    JIRA_ISSUE_TICKET = "jira issue ticket"
    GEOGRAPHIC_COORDINATES = "geographic coordinates"
    MAC_ADDRESS = "mac address"
    URL_SLUG = "url slug"
    C_IDENTIFIER = "C identifier"
    HYPHEN_WORD_BREAK = "hyphen word break"
    BITCOIN_ADDRESS = "bitcoin address"
    EMOJI = "emoji"
    CREDIT_CARD_NUMBER = "credit card number"
    PAN_FROM_GSTIN = "PAN from GSTIN"
    HAN_UNIFICATION = "han unification"
    PORT_NUMBER = "port number"
    DIGITAL_OBJECT_IDENTIFIER = "digital object identifier"
    HASHTAG = "hashtag"
